@@ -32,13 +32,13 @@ class TokenType(str, Enum):
     REFRESH_TOKEN = "refresh_token"
 
 
-@dataclass
+@dataclass(frozen=True)
 class JWTPortalPayload:
     id: int
     origin: str
 
 
-@dataclass
+@dataclass(frozen=True)
 class JWTPortalMemberPayload:
     id: int
     role_id: int
@@ -65,17 +65,12 @@ class AuthServerConnector:
         self._connector = AbmServiceConnector(config, context)
         logger.info(f"{type(self).__name__} inited")
 
-    async def get_access_token_payload(self, token: str, origin: str) -> JWTPayload:
-        answer = await self._connector.post(
-            path="v1/access_token/payload/get",
-            payload={"access_token": token},
-            headers={hdrs.ORIGIN: origin},
+    async def validate_access_token(self, token: str, origin: str) -> JWTPayload:
+        answer = await self._connector.get(
+            path="v1/auth/access_token/validate",
+            headers={
+                hdrs.ORIGIN: origin,
+                hdrs.AUTHORIZATION: f"Bearer {token}",
+            },
         )
         return dict_to_dataclass(answer, JWTPayload)
-
-    async def verify_access_token(self, token: str, origin: str) -> None:
-        await self._connector.post(
-            path="v1/auth/access_token/verify",
-            payload={"access_token": token},
-            headers={hdrs.ORIGIN: origin},
-        )
